==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-server/src/main/java/org/apache/hadoop/hbase/tool/coprocessor/CoprocessorMethods.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.tool.coprocessor;

import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.Set;

import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class CoprocessorMethods {
  private final Set<CoprocessorMethod> methods;

  public CoprocessorMethods() {
    methods = new HashSet<>();
  }

  public void addMethod(String name, String ... parameters) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(name).withParameters(parameters);
    methods.add(cpMethod);
  }

  public void addMethod(String name, Class<?> ... parameters) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(name).withParameters(parameters);
    methods.add(cpMethod);
  }

  public void addMethod(Method method) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(method.getName())
        .withParameters(method.getParameterTypes());
    methods.add(cpMethod);
  }

  public boolean hasMethod(String name, String ... parameters) {
    CoprocessorMethod method = new CoprocessorMethod(name).withParameters(parameters);
    return methods.contains(method);
  }

  public boolean hasMethod(String name, Class<?> ... parameters) {
    CoprocessorMethod method = new CoprocessorMethod(name).withParameters(parameters);
    return methods.contains(method);
  }

  public boolean hasMethod(Method method) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(method.getName())
        .withParameters(method.getParameterTypes());
    return methods.contains(cpMethod);
  }
}

==> hbase-2.5.9-src.tar.gz: hbase-2.5.9/hbase-server/src/main/java/org/apache/hadoop/hbase/tool/coprocessor/CoprocessorMethods.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.tool.coprocessor;

import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.Set;
import org.apache.yetus.audience.InterfaceAudience;

@InterfaceAudience.Private
public class CoprocessorMethods {
  private final Set<CoprocessorMethod> methods;

  public CoprocessorMethods() {
    methods = new HashSet<>();
  }

  public void addMethod(String name, String... parameters) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(name).withParameters(parameters);
    methods.add(cpMethod);
  }

  public void addMethod(String name, Class<?>... parameters) {
    CoprocessorMethod cpMethod = new CoprocessorMethod(name).withParameters(parameters);
    methods.add(cpMethod);
  }

  public void addMethod(Method method) {
    CoprocessorMethod cpMethod =
      new CoprocessorMethod(method.getName()).withParameters(method.getParameterTypes());
    methods.add(cpMethod);
  }

  public boolean hasMethod(String name, String... parameters) {
    CoprocessorMethod method = new CoprocessorMethod(name).withParameters(parameters);
    return methods.contains(method);
  }

  public boolean hasMethod(String name, Class<?>... parameters) {
    CoprocessorMethod method = new CoprocessorMethod(name).withParameters(parameters);
    return methods.contains(method);
  }

  public boolean hasMethod(Method method) {
    CoprocessorMethod cpMethod =
      new CoprocessorMethod(method.getName()).withParameters(method.getParameterTypes());
    return methods.contains(cpMethod);
  }
}
